/*
This file is part of IRCaBot.
IRCaBot is IRC logger with features.
Source code: https://notabug.org/acetone/ircabot.
Copyright (C) 2023, acetone.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#pragma once

#include "config.h"
#include "libirc/irc.h"

#include <QObject>

class IRCNetworkClient : public QObject
{
    Q_OBJECT
public:
    IRCNetworkClient(QObject* parent = nullptr);
    void setConfig(const Config::Network* config) { m_config = config; }
    // after config change; voiceGate, ircabotAdmin and autoReconnect have effect in run-time automatically
    void reloadChannelList();
    void start();
    const libircclient::Network* network() { return m_network; }

signals:
    void Event_NewDirectMessage(QString sender, QString text);
    void Event_NewChannelMessage(QString channel, QString sender, QString text);

private slots:
    void Slot_privMsg(libircclient::Parser* p);
    void Slot_adminIdentified(libircclient::Parser* p);
    void Slot_onDirectMessage(QString sender, QString text);
    void Slot_onChannelMessage(QString channel, QString sender, QString text);

private:
    const Config::Network* m_config;
    libircclient::Network* m_network = nullptr;
};

